local fs = require "nixio.fs"

m = Map("sshfs")

s = m:section(NamedSection, "sshfs", "sshfs", translate("SSHFS"), translate("SSHFS allows you to mount a remote filesystem using SFTP"))
s.addremove = false

o = s:option(Flag, "enabled", translate("Enable SSHFS"))
o.rmempty = false

o = s:option(Value, "hostname", translate("Hostname"), translate("Connection address"))
o.rmempty = false
o.datatype = "host"
o.placeholder = "example.com"

o = s:option(Value, "port", translate("Port"), translate("Port for the connection. If left empty a default of 22 will be used"))
o.datatype = "port"
o.placeholder = "22"

o = s:option(Value, "username", translate("Username"))
o.rmempty = false
o.datatype = "credentials_validate"
o.placeholder = "user"

o = s:option(Value, "password", translate("Password"))
o.rmempty = false
o.password = true
o.datatype = "credentials_validate"
o.placeholder = "pass"

o = s:option(Value, "mount_point", translate("Mount Point"), translate("A folder in device. Mount points must reside in the root <strong>/</strong> folder"))
o.rmempty = false
o.datatype = "fieldvalidation('^[/][^/]+$',0)"
o.maxlength = "512"
o.placeholder = "/sshmount"
o.validator_hint = translate("The mount point must only be in root directory")
o.write = function(self, section, value)
	local old_value = m.uci:get("sshfs", section, "mount_point")
	luci.util.ubus("file", "exec", { command="fusermount", params={ "-uzq", old_value }})
	luci.util.ubus("file", "exec", { command="rmdir", params={ old_value }})
	return AbstractValue.write(self, section, value)
end

o = s:option(Value, "mount_path", translate("Mount Path"), translate("A remote mount path that will be mounted"))
o.rmempty = false
o.datatype = "string"
o.maxlength = "512"
o.placeholder = "/home/"

return m
